package ch.zhaw.projekt2.turnierverwaltung;

import javafx.scene.control.Labeled;
import javafx.scene.control.MenuItem;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class LanguageConfigurator {

    private Language selectedLanguage;
    private Map<String,String> germanDictionary;
    private Map<String,String> englishDictionary;
    private List<Labeled> labelList;
    private List<MenuItem> menuItemList;

    public LanguageConfigurator() {
        selectedLanguage = Language.GERMAN;
        labelList = new ArrayList<>();
        menuItemList = new ArrayList<>();
        germanDictionary = new HashMap<>();
        englishDictionary = new HashMap<>();
        setUpDictionaries();
    }

    private void setUpDictionaries() {
        //Main
        germanDictionary.put("menuItemLanguage","Sprache");
        englishDictionary.put("menuItemLanguage","Language");
        germanDictionary.put("closeBtn","Beenden");
        englishDictionary.put("closeBtn","Close");
        germanDictionary.put("mainTitle","Turnier Manager");
        englishDictionary.put("mainTitle","Tournament Manager");
        //Tournamentlist
        germanDictionary.put("tournamentListTitle","Bestehende Turniere");
        englishDictionary.put("tournamentListTitle","Existing tournaments");
        germanDictionary.put("openBtn","Öffnen");
        englishDictionary.put("openBtn","Open");
        germanDictionary.put("deleteBtn","Löschen");
        englishDictionary.put("deleteBtn","Delete");
        germanDictionary.put("newTournamentFormularTitle","Neues Turnier erstellen");
        englishDictionary.put("newTournamentFormularTitle","Create new tournament");
        germanDictionary.put("tournamentNameLabel","Turnier Name:");
        englishDictionary.put("tournamentNameLabel","Tournament Name:");
        germanDictionary.put("tournamentModLabel","Turnier Modus");
        englishDictionary.put("tournamentModLabel","Tournament Mode");
        germanDictionary.put("createBtn","Erstellen");
        englishDictionary.put("createBtn","Create");
        //PlaceList
        germanDictionary.put("placeListTitle","Hinzugefügt");
        englishDictionary.put("placeListTitle","Added");
        germanDictionary.put("saveBtn","Speichern");
        englishDictionary.put("saveBtn","Save");
        germanDictionary.put("newplaceFormularTitle","Ort ändern/erstellen");
        englishDictionary.put("newplaceFormularTitle","Location change/create");
        //GameSchedule
        germanDictionary.put("treeView","Baumansicht");
        englishDictionary.put("treeView","Treeview");
        germanDictionary.put("createScheduleBtn","Spielplan erstellen");
        englishDictionary.put("createScheduleBtn","Create game schedule");
        germanDictionary.put("editParticipantBtn","Teilnehmer bearbeiten");
        englishDictionary.put("editParticipantBtn","Edit Participants");
        germanDictionary.put("editLocBtn","Orte bearbeiten");
        englishDictionary.put("editLocBtn","Edit Locations");
        germanDictionary.put("closeTournamentBtn","Turnier schliessen");
        englishDictionary.put("closeTournamentBtn","Close tournament");
        //ParticipantFormular
        germanDictionary.put("participantListTitle","Hinzugefügt");
        englishDictionary.put("participantListTitle","Added");
        germanDictionary.put("newParticipantFormularTitle","Teilnehmer ändern/erstellen");
        englishDictionary.put("newParticipantFormularTitle","Participant change/create");
        germanDictionary.put("participantNameLabel","Name:");
        englishDictionary.put("participantNameLabel","Name:");
        germanDictionary.put("firstNameLabel","Vorname:");
        englishDictionary.put("firstNameLabel","First Name:");
        germanDictionary.put("phoneNumberLabel","Telefon:");
        englishDictionary.put("phoneNumberLabel","Phone:");
        germanDictionary.put("birthDateLabel","Geb. Datum:");
        englishDictionary.put("birthDateLabel","Birthday:");
        //Game
        germanDictionary.put("locationLabel","Ort:");
        englishDictionary.put("locationLabel","Location:");
    }

    public void translateGUI() {
        String word = "";
        for (Labeled label : labelList) {
            switch (selectedLanguage) {
                case GERMAN -> {
                    word = germanDictionary.get(label.getId());
                }
                case ENGLISH -> {
                    word = englishDictionary.get(label.getId());
                }
            }
            if(word != null) {
                label.setText(word);
            } else {
                //TODO LOG
            }
        }

        for (MenuItem item : menuItemList) {
            switch (selectedLanguage) {
                case GERMAN -> {
                    word = germanDictionary.get(item.getId());
                }
                case ENGLISH -> {
                    word = englishDictionary.get(item.getId());
                }
            }
            if(word != null) {
                item.setText(word);
            } else {
                //TODO LOG
            }
        }
    }

    public void recieveLabel(Labeled label) {
        if (label != null) {
            labelList.add(label);
        }
    }

    public void recieveMenuItem(MenuItem item) {
        menuItemList.add(item);
    }

    public void changeLanguage(Language language) {
        this.selectedLanguage = language;
        translateGUI();
    }

    public enum Language {
        ENGLISH,GERMAN
    }
}
